@@ -217,6 +217,7 @@ static int nm_sig_cb(unsigned int subsys, unsigned int signal,
 /* TODO: put in a separate file ? */
 
 static const struct value_string nokia_msgt_name[] = {
+	{ 0x7F, "NOKIA_BTS_RSSI_VSWR_COUNTERS_REQ" },
 	{ 0x80, "NOKIA_BTS_CONF_DATA" },
 	{ 0x81, "NOKIA_BTS_ACK" },
 	{ 0x82, "NOKIA_BTS_OMU_STARTED" },
@@ -275,6 +276,20 @@ static const struct value_string nokia_msgt_name[] = {
 	{ 0xB7, "NOKIA_BTS_LCS_ANSWER" },
 	{ 0xB8, "NOKIA_BTS_LMU_FN_OFFSET_COMMAND" },
 	{ 0xB9, "NOKIA_BTS_LMU_FN_OFFSET_ANSWER" },
+	{ 0xBA, "NOKIA_BTS_LAPD_CTR_REP" },
+	{ 0xBB, "NOKIA_BTS_TRX_CONFIGURATION_UPDATE" },
+	{ 0xBC, "NOKIA_BTS_DYNAMIC_LOAD_INFO" },
+	{ 0xBD, "NOKIA_BTS_CONF_DATA_BS2" },
+	{ 0xBE, "NOKIA_BTS_REGISTRY_REQ" },
+	{ 0xBF, "NOKIA_BTS_SFS_UPLOAD_REQ" },
+	{ 0xC0, "NOKIA_BTS_DELAY_MEAS_REQ" },
+	{ 0xC1, "NOKIA_BTS_DELAY_MEAS_ACK" },
+	{ 0xC2, "NOKIA_BTS_PABIS_MEAS_REQ" },
+	{ 0xC3, "NOKIA_BTS_PABIS_MEAS_ACK" },
+	{ 0xC4, "NOKIA_BSC_RESET_INFO" },
+	{ 0xC5, "NOKIA_BSC_RESET_COMPL" },
+	{ 0xC6, "NOKIA_BSC_RESET_COMPL_ANSWER" },
+	{ 0xC7, "NOKIA_BTS_RSSI_VSWR_COUNTERS" },
 	{ 0, NULL }
 };
 
@@ -456,7 +471,88 @@ static const struct value_string nokia_element_name[] = {
 	{ 0xAA, "TSC" },
 	{ 0xAB, "Special TX Power Setting" },
 	{ 0xAC, "Optional sync settings" },
+	{ 0xAD, "STIRC Option Setting" },
+	{ 0xAE, "Rx Difference Samples Count" },
+	{ 0xAF, "BTS Object Mapping" },
+	{ 0xB0, "Abis Mapping" },
+	{ 0xB1, "LAPDm T200 Values" },
+	{ 0xB2, "DTRX info" },
+	{ 0xB3, "Link and Counters" },
+	{ 0xB4, "TRS and BTS licensing" },
+	{ 0xB5, "TRX DDU association" },
+	{ 0xB6, "Power control reason" },
+	{ 0xB7, "CSDAP" },
+	{ 0xB8, "BS2 parameters" },
+	{ 0xB9, "BSC parameters" },
+	{ 0xBA, "BTS parameters" },
+	{ 0xBB, "TRX parameters" },
+	{ 0xBC, "HO parameters" },
+	{ 0xBD, "POC parameters" },
+	{ 0xBE, "ADJC parameters" },
+	{ 0xBF, "ADJC object" },
+	{ 0xC0, "UADJC parameters" },
+	{ 0xC1, "UADJC object" },
+	{ 0xC2, "BTS PCM id" },
+	{ 0xC3, "Segment Object id" },
+	{ 0xC4, "Cell load parameters" },
+	{ 0xC5, "Dynamic cell load info" },
+	{ 0xC6, "BSC Release information" },
+	{ 0xC7, "Complete data" },
+	{ 0xC8, "OMUSIG PCM info" },
+	{ 0xC9, "Line type" },
+	{ 0xCA, "Concurrent OMUSIGs priorities" },
+	{ 0xCB, "OMUSIG Priority" },
+	{ 0xCC, "OSC support" },
+	{ 0xCD, "CSDAP id" },
+	{ 0xCE, "CSDAP parameters" },
+	{ 0xCF, "Local Switching Counters" },
+	{ 0xD0, "TX queue handling parameters" },
+	{ 0xD1, "Valid History Records" },
+	{ 0xD2, "Measurement Operation Status" },
+	{ 0xD3, "Abis Delay Counters" },
+	{ 0xD4, "Abis Measurement channel" },
+	{ 0xD5, "Packet Abis BCF group configuration" },
+	{ 0xD6, "Traffic to DSCP mapping" },
+	{ 0xD7, "UL Shaping parameters" },
+	{ 0xD8, "Traffic scheduling" },
+	{ 0xD9, "Random Fill Bits usage" },
+	{ 0xDA, "Packet Abis BCF group id" },
+	{ 0xDB, "UDP" },
+	{ 0xDC, "Backhaul utilization monitor parameters" },
+	{ 0xDD, "Packet loss monitor parameters" },
+	{ 0xDE, "Congestion control" },
+	{ 0xDF, "Congestion reaction hysteresis parameters" },
+	{ 0xE0, "Multiplexing parameters" },
+	{ 0xE1, "IP addresses" },
+	{ 0xE2, "TRX feature capability" },
+	{ 0xE3, "Packet Abis If configuration" },
+	{ 0xE4, "BTS IPv4 address C/U-plane" },
+	{ 0xE5, "IPv4 address" },
+	{ 0xE6, "Subnet mask" },
+	{ 0xE7, "BSC IPv4 address C-plane" },
+	{ 0xE8, "BSC IPv4 address CS U-plane" },
+	{ 0xE9, "BSC IPv4 address PS U-plane" },
+	{ 0xEA, "MC-PPP class map" },
+	{ 0xEB, "SCTP parameters" },
+	{ 0xEC, "Packet Abis mapping" },
+	{ 0xED, "Sig ID" },
+	{ 0xEE, "Packet Abis mapping" },
+	{ 0xEF, "Measurement Request Type" },
+	{ 0xF0, "Peer BTS info" },
+	{ 0xF1, "Packet Abis Counters" },
+	{ 0xF2, "Waiting time for BSC restarting" },
+	{ 0xF3, "Peer BCF ID" },
+	{ 0xF4, "TRX starting mode" },
+	{ 0xF5, "GSM-R configuration" },
+	{ 0xF6, "DSCP to VLAN priority mapping" },
+	{ 0xF7, "TRX Assosiation" },
+	{ 0xF8, "Power Finetuning" },
+	{ 0xF9, "Abis Delay Measurement UDP port" },
 	{ 0xFA, "Abis If parameters" },
+	{ 0xFB, "PDV" },
+	{ 0xFC, "Horizon BTS parameters" },
+	{ 0xFD, "reserved" },
+	{ 0xFE, "Radio Module SW" },
 	{ 0, NULL }
 };
 
@@ -1635,27 +1731,6 @@ static int abis_nm_rcvmsg_fom(struct msgb *mb)
 			osmo_timer_setup(&bts->nokia.reset_timer, reset_timer_cb, bts);
 			osmo_timer_schedule(&bts->nokia.reset_timer, 0, 0);
 		}
-
-		/* ACK for CONF DATA message ? */
-		if (bts->nokia.configured != 0) {
-			/* start TRX  (RSL link) */
-
-			struct gsm_e1_subslot *e1_link =
-					&sign_link->trx->rsl_e1_link;
-			struct e1inp_line *line;
-
-			bts->nokia.configured = 0;
-
-			/* RSL Link */
-			line = e1inp_line_find(e1_link->e1_nr);
-			if (!line) {
-				LOG_BTS(bts, DLINP, LOGL_ERROR, "RSL link referring to "
-					"non-existing E1 line %u\n", e1_link->e1_nr);
-				return -ENOMEM;
-			}
-			/* start TRX */
-			start_sabm_in_line(line, 1, SAPI_RSL);	/* start only RSL */
-		}
 		break;
 	case NOKIA_MSG_STATE_CHANGED:
 		/* send ACK */
@@ -1664,6 +1739,21 @@ static int abis_nm_rcvmsg_fom(struct msgb *mb)
 	case NOKIA_MSG_CONF_COMPLETE:
 		/* send ACK */
 		abis_nm_ack(bts, ref);
+		if (bts->nokia.configured != 0) {
+			/* start TRX  (RSL link) */
+			struct gsm_e1_subslot *e1_link = &sign_link->trx->rsl_e1_link;
+			struct e1inp_line *line;
+			bts->nokia.configured = 0;
+			/* RSL Link */
+			line = e1inp_line_find(e1_link->e1_nr);
+			if (!line) {
+					LOG_BTS(bts, DLINP, LOGL_ERROR, "RSL link referring to "
+						"non-existing E1 line %u\n", e1_link->e1_nr);
+					return -ENOMEM;
+			}
+			/* start TRX */
+			start_sabm_in_line(line, 1, SAPI_RSL);  /* start only RSL */
+		}
 		/* fake 12.21 OM */
 		nokia_abis_nm_fake_1221_ok(bts);
 		break;
